[vlc-devel] commit: aout_VolumeMute -> aout_ToggleMute ( Rémi Denis-Courmont )

git version control git at videolan.org
Thu Jul 9 20:25:24 CEST 2009


vlc | branch: master | Rémi Denis-Courmont <remi at remlab.net> | Thu Jul  9 21:22:47 2009 +0300| [604adb7afc67e0c1789fc2c5dc95d4fb8a1ff5bb] | committer: Rémi Denis-Courmont 

aout_VolumeMute -> aout_ToggleMute

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=604adb7afc67e0c1789fc2c5dc95d4fb8a1ff5bb
---

 include/vlc_aout.h                               |    4 ++--
 modules/control/gestures.c                       |    2 +-
 modules/control/hotkeys.c                        |    2 +-
 modules/gui/beos/InterfaceWindow.cpp             |    2 +-
 modules/gui/qt4/actions_manager.cpp              |    2 +-
 modules/gui/qt4/components/controller_widget.cpp |    2 +-
 modules/gui/skins2/commands/cmd_input.cpp        |    2 +-
 src/audio_output/intf.c                          |    4 ++--
 src/control/audio.c                              |    4 ++--
 src/libvlccore.sym                               |    2 +-
 10 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/include/vlc_aout.h b/include/vlc_aout.h
index 21b67fb..f1ecbd5 100644
--- a/include/vlc_aout.h
+++ b/include/vlc_aout.h
@@ -451,8 +451,8 @@ VLC_EXPORT( int, __aout_VolumeInfos, ( vlc_object_t *, audio_volume_t * ) );
 VLC_EXPORT( int, __aout_VolumeUp, ( vlc_object_t *, int, audio_volume_t * ) );
 #define aout_VolumeDown(a, b, c) __aout_VolumeDown(VLC_OBJECT(a), b, c)
 VLC_EXPORT( int, __aout_VolumeDown, ( vlc_object_t *, int, audio_volume_t * ) );
-#define aout_VolumeMute(a, b) __aout_VolumeMute(VLC_OBJECT(a), b)
-VLC_EXPORT( int, __aout_VolumeMute, ( vlc_object_t *, audio_volume_t * ) );
+#define aout_ToggleMute(a, b) __aout_ToggleMute(VLC_OBJECT(a), b)
+VLC_EXPORT( int, __aout_ToggleMute, ( vlc_object_t *, audio_volume_t * ) );
 VLC_EXPORT( int, aout_FindAndRestart, ( vlc_object_t *, const char *, vlc_value_t, vlc_value_t, void * ) );
 VLC_EXPORT( int, aout_ChannelsRestart, ( vlc_object_t *, const char *, vlc_value_t, vlc_value_t, void * ) );
 
diff --git a/modules/control/gestures.c b/modules/control/gestures.c
index ef9e5ac..2f4b003 100644
--- a/modules/control/gestures.c
+++ b/modules/control/gestures.c
@@ -286,7 +286,7 @@ static void RunIntf( intf_thread_t *p_intf )
             case GESTURE(UP,DOWN,NONE,NONE):
             case GESTURE(DOWN,UP,NONE,NONE):
                 msg_Dbg( p_intf, "Mute sound" );
-                aout_VolumeMute( p_intf, NULL );
+                aout_ToggleMute( p_intf, NULL );
                 break;
 
             case GESTURE(UP,RIGHT,NONE,NONE):
diff --git a/modules/control/hotkeys.c b/modules/control/hotkeys.c
index 817fd0a..f6cb257 100644
--- a/modules/control/hotkeys.c
+++ b/modules/control/hotkeys.c
@@ -197,7 +197,7 @@ static int PutAction( intf_thread_t *p_intf, int i_action )
         case ACTIONID_VOL_MUTE:
         {
             audio_volume_t i_newvol = -1;
-            aout_VolumeMute( p_intf, &i_newvol );
+            aout_ToggleMute( p_intf, &i_newvol );
             if( p_vout )
             {
                 if( i_newvol == 0 )
diff --git a/modules/gui/beos/InterfaceWindow.cpp b/modules/gui/beos/InterfaceWindow.cpp
index 79873d5..59b688c 100644
--- a/modules/gui/beos/InterfaceWindow.cpp
+++ b/modules/gui/beos/InterfaceWindow.cpp
@@ -542,7 +542,7 @@ void InterfaceWindow::MessageReceived( BMessage * p_message )
             break;
 
         case VOLUME_MUTE:
-            aout_VolumeMute( p_intf, NULL );
+            aout_ToggleMute( p_intf, NULL );
             break;
 
         case SELECT_CHANNEL:
diff --git a/modules/gui/qt4/actions_manager.cpp b/modules/gui/qt4/actions_manager.cpp
index ed5cd71..e4c0053 100644
--- a/modules/gui/qt4/actions_manager.cpp
+++ b/modules/gui/qt4/actions_manager.cpp
@@ -170,7 +170,7 @@ void ActionsManager::frame()
 
 void ActionsManager::toggleMuteAudio()
 {
-     aout_VolumeMute( p_intf, NULL );
+     aout_ToggleMute( p_intf, NULL );
 }
 
 void ActionsManager::AudioUp()
diff --git a/modules/gui/qt4/components/controller_widget.cpp b/modules/gui/qt4/components/controller_widget.cpp
index 5276cd8..a680339 100644
--- a/modules/gui/qt4/components/controller_widget.cpp
+++ b/modules/gui/qt4/components/controller_widget.cpp
@@ -184,7 +184,7 @@ bool SoundWidget::eventFilter( QObject *obj, QEvent *e )
         }
         else
         {
-            aout_VolumeMute( p_intf, NULL );
+            aout_ToggleMute( p_intf, NULL );
         }
         e->accept();
         return true;
diff --git a/modules/gui/skins2/commands/cmd_input.cpp b/modules/gui/skins2/commands/cmd_input.cpp
index 4e76107..c91b0aa 100644
--- a/modules/gui/skins2/commands/cmd_input.cpp
+++ b/modules/gui/skins2/commands/cmd_input.cpp
@@ -111,7 +111,7 @@ void CmdFaster::execute()
 
 void CmdMute::execute()
 {
-    aout_VolumeMute( getIntf(), NULL );
+    aout_TogleMute( getIntf(), NULL );
 }
 
 
diff --git a/src/control/audio.c b/src/control/audio.c
index fb96b70..0146bbe 100644
--- a/src/control/audio.c
+++ b/src/control/audio.c
@@ -321,7 +321,7 @@ void libvlc_audio_toggle_mute( libvlc_instance_t *p_instance,
 {
     VLC_UNUSED(p_e);
 
-    aout_VolumeMute( p_instance->p_libvlc_int, NULL );
+    aout_ToggleMute( p_instance->p_libvlc_int, NULL );
 }
 
 int libvlc_audio_get_mute( libvlc_instance_t *p_instance,
@@ -335,7 +335,7 @@ void libvlc_audio_set_mute( libvlc_instance_t *p_instance, int mute,
 {
     if ( mute ^ libvlc_audio_get_mute( p_instance, p_e ) )
     {
-        aout_VolumeMute( p_instance->p_libvlc_int, NULL );
+        aout_ToggleMute( p_instance->p_libvlc_int, NULL );
     }
 }
 
diff --git a/src/libvlccore.sym b/src/libvlccore.sym
index 3d1a407..bb2fbc1 100644
--- a/src/libvlccore.sym
+++ b/src/libvlccore.sym
@@ -30,7 +30,7 @@ aout_VisualChange
 __aout_VolumeDown
 __aout_VolumeGet
 __aout_VolumeInfos
-__aout_VolumeMute
+__aout_ToggleMute
 aout_VolumeNoneInit
 __aout_VolumeSet
 aout_VolumeSoftInit




More information about the vlc-devel mailing list
diff --git a/src/audio_output/intf.c b/src/audio_output/intf.c
index a780db6..409ca68 100644
--- a/src/audio_output/intf.c
+++ b/src/audio_output/intf.c
@@ -228,12 +228,12 @@ int __aout_VolumeDown( vlc_object_t * p_object, int i_nb_steps,
 }
 
 /*****************************************************************************
  * aout_VolumeMute : Mute/un-mute the output volume
  *****************************************************************************
  * If pi_volume != NULL, *pi_volume will contain the volume at the end of the
  * function (muted => 0).
  *****************************************************************************/
-int __aout_VolumeMute( vlc_object_t * p_object, audio_volume_t * pi_volume )
+int __aout_ToggleMute( vlc_object_t * p_object, audio_volume_t * pi_volume )
 {
     int i_result;
     audio_volume_t i_volume;
@@ -228,12 +228,12 @@ int __aout_VolumeDown( vlc_object_t * p_object, int i_nb_steps,
 
 /*****************************************************************************
- * aout_VolumeMute : Mute/un-mute the output volume
+ * aout_ToggleMute : Mute/un-mute the output volume
  *****************************************************************************
  * If pi_volume != NULL, *pi_volume will contain the volume at the end of the